--- src/Mod/Import/App/ImportOCAF2.h.orig	2023-01-21 23:09:25.522104000 +0100
+++ src/Mod/Import/App/ImportOCAF2.h	2023-01-21 23:09:52.176852000 +0100
@@ -30,6 +30,7 @@
 #include <TDF_LabelMapHasher.hxx>
 #include <climits>
 #include <string>
+#include <array>
 #include <set>
 #include <map>
 #include <unordered_map>
