--- src/Gui/Selection.h.orig	2023-01-21 23:23:47.647852000 +0100
+++ src/Gui/Selection.h	2023-01-21 23:24:04.167678000 +0100
@@ -25,6 +25,7 @@
 #define GUI_SELECTION_H
 
 #include <deque>
+#include <array>
 #include <list>
 #include <string>
 #include <vector>
